#!/bin/bash

# Install default Office fonts
# see: https://helpcenter.onlyoffice.com/de/server/linux/document/install-fonts.aspx

# If DocumentServer is running within a container
# find the container with:
# sudo docker ps -a
# and enter that container
# docker exec -it <documentserver> /bin/bash
# e.g. 
# docker exec -it onlyoffice-document-server /bin/bash


cd /tmp
sudo mkdir -p /usr/share/fonts/truetype
sudo mkdir -p /var/www/onlyoffice/documentserver/core-fonts/garr

sudo apt update
sudo apt -y install unzip
sudo apt -y install fontconfig # for fc-cache

function get_font {
    wget "http://legionfonts.com/download/$1"
    unzip "$1"
    sudo cp "$2.ttf" /usr/share/fonts/truetype
    sudo cp "$2.ttf" /var/www/onlyoffice/documentserver/core-fonts/garr
    rm "$2.ttf"
    rm "$1"
}

# Optionally remove extra fonts
sudo apt -y remove fonts-taml fonts-telu fonts-mlym
sudo apt -y remove fonts-lohit-telu fonts-lohit-taml fonts-lohit-taml fonts-lohit-orya fonts-lohit-mlym fonts-lohit-knda fonts-lohit-guru
sudo apt -y remove fonts-deva fonts-gujr fonts-guru fonts-knda fonts-lohit-beng-assamese fonts-lohit-beng-bengali fonts-lohit-deva fonts-lohit-gujr
sudo apt -y remove fonts-kacst fonts-kacst-one fonts-pagul
sudo apt -y remove fonts-thai-tlwg-web fonts-tlwg-garuda fonts-tlwg-garuda-otf fonts-tlwg-garuda-ttf
sudo apt -y remove fonts-noto-mono fonts-noto-cjk
sudo apt -y remove fonts-khmeros-core fonts-khmeros
sudo apt -y remove fonts-lklug-sinhala fonts-tibetan-machine fonts-sil-padauk

sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/lohit-*
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/arphic-ukai
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/kacst*
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/abyissinica
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/ttf-khmeros*
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/wqy-zenhei
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/noto
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/fonts-beng-*
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/fonts-gujr-*
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/fonts-telu-*
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/padauk
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/tibetan-machine
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/samyak-*
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/takao-*
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/nanum
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/ancient-scripts
sudo rm -r /var/www/onlyoffice/documentserver/core-fonts/asana

# Download and install fonts
get_font arial Arial
get_font calibri Calibri
get_font courier-new 'Courier New'
get_font symbol Symbol
get_font times-new-roman 'Times New Roman'
get_font tw-cen-mt 'Tw Cen MT'
get_font tw-cen-mt-condensed 'Tw Cen MT Condensed'
get_font cambria Cambria

# Refresh the cache
sudo fc-cache -fv

# OnlyOffice-provided script
/usr/bin/documentserver-generate-allfonts.sh

