#!/bin/bash

ONLYOFFICE_HOME="/var/www/onlyoffice"
CONTAINER_DATA_STORAGE="/var/www/onlyoffice/Data"

ONLYOFFICE_DATA="$ONLYOFFICE_HOME/server_data"
ONLYOFFICE_BACKUP="$ONLYOFFICE_HOME/server_backup"

DATE="$1"

if [[ -z "$DATE" ]]; then
    if [[ -e "$ONLYOFFICE_BACKUP/LATEST" ]]; then
      DATE=`cat "$ONLYOFFICE_BACKUP/LATEST"`
    else
      echo "Usage: restore.sh <date>"
      exit -1
    fi
fi

echo "Restoring ONLYOFFICE backup for $DATE..."

SQL_ARCHIVE="$ONLYOFFICE_BACKUP/$DATE.tgz"
DATA_ARCHIVE="$ONLYOFFICE_BACKUP/files-$DATE.tgz"
SQL_FILE="$DATE.sql"

if [[ -e "$SQL_ARCHIVE" ]]; then
  echo "SQL archive \"$SQL_ARCHIVE\" found"
else
  echo "SQL archive \"$SQL_ARCHIVE\" not found! Aborting..."
  exit -1
fi

if [[ -e "$DATA_ARCHIVE" ]]; then
  echo "Data archive \"$DATA_ARCHIVE\" found"
else
  echo "Data archive \"$DATA_ARCHIVE\" not found! Aborting..."
  exit -1
fi

echo "Stopping ONLYOFFICE..."
service monoserve stop

echo "Restoring sql..."
cd $ONLYOFFICE_BACKUP
tar -xf $SQL_ARCHIVE
CONTAINER_NAME mysql onlyoffice < $SQL_FILE
rm $SQL_FILE

echo "Restoring data..."
cd $ONLYOFFICE_DATA
rm -R *
tar -xf $DATA_ARCHIVE

echo "Starting ONLYOFFICE..."
service monoserve start

